@@ -1,12 +1,15 @@
 from json import dumps
 from typing import Optional, Union, Tuple, Dict
 
-def json(obj: Optional[Union[dict, list, int, float, str, bool]]) -> Tuple[str, Dict[str, str], str]:
+from .schemas import JsonType, ReturnType
+
+
+def json(obj: JsonType) -> ReturnType:
     return ('200 OK', {'Content-Type': 'application/json'}, dumps(obj))
 
-def redirect(url: str) -> Tuple[str, Dict[str, str], str]:
+def redirect(url: str) -> ReturnType:
     headers = {
         'Content-Type': 'text/plain',
         'Location': url
     }
-    return ('301 Moved Permanently', headers, 'Redirecting...')
\ No newline at end of file
+    return ('301 Moved Permanently', headers, f'Redirecting to {url}...')
\ No newline at end of file
